@@ -12,6 +12,8 @@ from unique_toolkit._common.endpoint_builder import (
     PathParamsType,
     PayloadParamSpec,
     PayloadType,
+    QueryParamsSpec,
+    QueryParamsType,
     ResponseType,
 )
 
@@ -61,6 +63,8 @@ def build_fake_requestor(
             PathParamsType,
             PayloadParamSpec,
             PayloadType,
+            QueryParamsSpec,
+            QueryParamsType,
             ResponseType,
         ]
     ],
@@ -78,8 +82,8 @@ def build_fake_requestor(
             **kwargs: CombinedParamsSpec.kwargs,
         ) -> ResponseType:
             try:
-                path_params, payload_model = cls._operation.models_from_combined(
-                    combined=kwargs
+                path_params, payload_model, query_params = (
+                    cls._operation.models_from_combined(combined=kwargs)
                 )
             except Exception as e:
                 raise ValueError(
@@ -113,6 +117,8 @@ def build_request_requestor(
             PathParamsType,
             PayloadParamSpec,
             PayloadType,
+            QueryParamsSpec,
+            QueryParamsType,
             ResponseType,
         ]
     ],
@@ -131,8 +137,8 @@ def build_request_requestor(
             **kwargs: CombinedParamsSpec.kwargs,
         ) -> ResponseType:
             # Create separate instances for path params and payload using endpoint helper
-            path_params, payload_model = cls._operation.models_from_combined(
-                combined=kwargs
+            path_params, payload_model, query_params = (
+                cls._operation.models_from_combined(combined=kwargs)
             )
 
             path = cls._operation.create_path_from_model(
@@ -144,12 +150,19 @@ def build_request_requestor(
             payload = cls._operation.create_payload_from_model(
                 payload_model, model_dump_options=cls._operation.payload_dump_options()
             )
+            request_method = cls._operation.request_method()
+
+            params = cls._operation.create_query_params_from_model(
+                query_params=query_params,
+                model_dump_options=cls._operation.query_params_dump_options(),
+            )
 
             response = requests.request(
-                method=cls._operation.request_method(),
+                method=request_method,
                 url=url,
                 headers=context.headers,
                 json=payload,
+                params=params,
             )
 
             response_json = response.json()
@@ -181,6 +194,8 @@ def build_httpx_requestor(
             PathParamsType,
             PayloadParamSpec,
             PayloadType,
+            QueryParamsSpec,
+            QueryParamsType,
             ResponseType,
         ]
     ],
@@ -200,8 +215,8 @@ def build_httpx_requestor(
         ) -> ResponseType:
             headers = context.headers or {}
 
-            path_params, payload_model = cls._operation.models_from_combined(
-                combined=kwargs
+            path_params, payload_model, query_model = (
+                cls._operation.models_from_combined(combined=kwargs)
             )
 
             path = cls._operation.create_path_from_model(
@@ -209,15 +224,24 @@ def build_httpx_requestor(
             )
             url = urljoin(context.base_url, path)
             _verify_url(url)
+
+            payload = cls._operation.create_payload_from_model(
+                payload_model,
+                model_dump_options=cls._operation.payload_dump_options(),
+            )
+
+            query_params = cls._operation.create_query_params_from_model(
+                query_params=query_model,
+                model_dump_options=cls._operation.query_params_dump_options(),
+            )
+
             with httpx.Client() as client:
                 response = client.request(
                     method=cls._operation.request_method(),
                     url=url,
                     headers=headers,
-                    json=cls._operation.create_payload_from_model(
-                        payload_model,
-                        model_dump_options=cls._operation.payload_dump_options(),
-                    ),
+                    json=payload,
+                    params=query_params,
                 )
                 response_json = response.json()
                 return cls._operation.handle_response(
@@ -234,8 +258,8 @@ def build_httpx_requestor(
         ) -> ResponseType:
             headers = context.headers or {}
 
-            path_params, payload_model = cls._operation.models_from_combined(
-                combined=kwargs
+            path_params, payload_model, query_model = (
+                cls._operation.models_from_combined(combined=kwargs)
             )
 
             path = cls._operation.create_path_from_model(
@@ -243,15 +267,24 @@ def build_httpx_requestor(
             )
             url = urljoin(context.base_url, path)
             _verify_url(url)
+
+            payload = cls._operation.create_payload_from_model(
+                payload_model,
+                model_dump_options=cls._operation.payload_dump_options(),
+            )
+
+            query_params = cls._operation.create_query_params_from_model(
+                query_params=query_model,
+                model_dump_options=cls._operation.query_params_dump_options(),
+            )
+
             async with httpx.AsyncClient() as client:
                 response = await client.request(
                     method=cls._operation.request_method(),
                     url=url,
                     headers=headers,
-                    json=cls._operation.create_payload_from_model(
-                        payload_model,
-                        model_dump_options=cls._operation.payload_dump_options(),
-                    ),
+                    json=payload,
+                    params=query_params,
                 )
                 response_json = response.json()
                 return cls._operation.handle_response(
@@ -269,6 +302,8 @@ def build_aiohttp_requestor(
             PathParamsType,
             PayloadParamSpec,
             PayloadType,
+            QueryParamsSpec,
+            QueryParamsType,
             ResponseType,
         ]
     ],
@@ -300,8 +335,8 @@ def build_aiohttp_requestor(
         ) -> ResponseType:
             headers = context.headers or {}
 
-            path_params, payload_model = cls._operation.models_from_combined(
-                combined=kwargs
+            path_params, payload_model, query_model = (
+                cls._operation.models_from_combined(combined=kwargs)
             )
             path = cls._operation.create_path_from_model(
                 path_params, model_dump_options=cls._operation.path_dump_options()
@@ -318,6 +353,10 @@ def build_aiohttp_requestor(
                         payload=payload_model,
                         model_dump_options=cls._operation.payload_dump_options(),
                     ),
+                    params=cls._operation.create_query_params_from_model(
+                        query_params=query_model,
+                        model_dump_options=cls._operation.query_params_dump_options(),
+                    ),
                 )
                 response_json = await response.json()
                 return cls._operation.handle_response(
@@ -343,6 +382,8 @@ def build_requestor(
             PathParamsType,
             PayloadParamSpec,
             PayloadType,
+            QueryParamsSpec,
+            QueryParamsType,
             ResponseType,
         ]
     ],
@@ -353,7 +394,8 @@ def build_requestor(
     match requestor_type:
         case RequestorType.REQUESTS:
             return build_request_requestor(
-                operation_type=operation_type, combined_model=combined_model
+                operation_type=operation_type,
+                combined_model=combined_model,
             )
         case RequestorType.FAKE:
             if return_value is None:
@@ -376,7 +418,10 @@ def build_requestor(
 if __name__ == "__main__":
     from string import Template
 
-    from unique_toolkit._common.endpoint_builder import build_api_operation
+    from unique_toolkit._common.endpoint_builder import (
+        HttpMethods,
+        build_api_operation,
+    )
 
     class GetUserPathParams(BaseModel):
         user_id: int
@@ -384,11 +429,15 @@ if __name__ == "__main__":
     class GetUserRequestBody(BaseModel):
         include_profile: bool = False
 
+    class GetUserQueryParams(BaseModel):
+        page: int = 1
+        limit: int = 10
+
     class UserResponse(BaseModel):
         id: int
         name: str
 
-    class CombinedParams(GetUserPathParams, GetUserRequestBody):
+    class CombinedParams(GetUserPathParams, GetUserRequestBody, GetUserQueryParams):
         pass
 
     UserEndpoint = build_api_operation(
@@ -396,6 +445,7 @@ if __name__ == "__main__":
         path_template=Template("/users/{user_id}"),
         path_params_constructor=GetUserPathParams,
         payload_constructor=GetUserRequestBody,
+        query_params_constructor=GetUserQueryParams,
         response_model_type=UserResponse,
     )
 
