@@ -2,25 +2,35 @@ from unique_toolkit.agentic.tools.a2a.config import ExtendedSubAgentToolConfig
 from unique_toolkit.agentic.tools.a2a.evaluation import (
     SubAgentEvaluationService,
     SubAgentEvaluationServiceConfig,
+    SubAgentEvaluationSpec,
 )
 from unique_toolkit.agentic.tools.a2a.manager import A2AManager
 from unique_toolkit.agentic.tools.a2a.postprocessing import (
-    SubAgentResponsesPostprocessor,
+    SubAgentDisplaySpec,
+    SubAgentReferencesPostprocessor,
+    SubAgentResponsesDisplayPostprocessor,
+    SubAgentResponsesPostprocessorConfig,
 )
 from unique_toolkit.agentic.tools.a2a.prompts import (
     REFERENCING_INSTRUCTIONS_FOR_SYSTEM_PROMPT,
     REFERENCING_INSTRUCTIONS_FOR_USER_PROMPT,
 )
+from unique_toolkit.agentic.tools.a2a.response_watcher import SubAgentResponseWatcher
 from unique_toolkit.agentic.tools.a2a.tool import SubAgentTool, SubAgentToolConfig
 
 __all__ = [
     "SubAgentToolConfig",
     "SubAgentTool",
-    "SubAgentResponsesPostprocessor",
+    "SubAgentResponsesDisplayPostprocessor",
+    "SubAgentResponsesPostprocessorConfig",
+    "SubAgentDisplaySpec",
     "A2AManager",
     "ExtendedSubAgentToolConfig",
     "SubAgentEvaluationServiceConfig",
     "SubAgentEvaluationService",
     "REFERENCING_INSTRUCTIONS_FOR_SYSTEM_PROMPT",
     "REFERENCING_INSTRUCTIONS_FOR_USER_PROMPT",
+    "SubAgentResponseWatcher",
+    "SubAgentReferencesPostprocessor",
+    "SubAgentEvaluationSpec",
 ]
