@@ -4,10 +4,12 @@ from unique_toolkit.agentic.tools.a2a.evaluation.config import (
 )
 from unique_toolkit.agentic.tools.a2a.evaluation.evaluator import (
     SubAgentEvaluationService,
+    SubAgentEvaluationSpec,
 )
 
 __all__ = [
     "SubAgentEvaluationService",
     "SubAgentEvaluationServiceConfig",
     "SubAgentEvaluationConfig",
+    "SubAgentEvaluationSpec",
 ]
